@@ -16,6 +16,7 @@ import urllib
 import warnings
 from codecs import getwriter
 from collections.abc import Mapping, MutableMapping, MutableSequence, Sized
+from importlib.resources import files
 from typing import IO, Any, Callable, Optional, Union, cast
 
 import argcomplete
@@ -96,7 +97,6 @@ from .utils import (
     CWLOutputType,
     HasReqsHints,
     adjustDirObjs,
-    files,
     normalizeFilesDirs,
     processes_to_kill,
     trim_listing,
@@ -119,7 +119,6 @@ def _terminate_processes() -> None:
     continuing to execute while it kills the processes that they've
     spawned. This may occasionally lead to unexpected behaviour.
     """
-    global docker_exe
     # It's possible that another thread will spawn a new task while
     # we're executing, so it's not safe to use a for loop here.
     while processes_to_kill:
@@ -305,7 +304,7 @@ def realize_input_schema(
             if isinstance(entry["type"], Mapping):
                 entry["type"] = cast(
                     CWLOutputType,
-                    realize_input_schema([cast(CWLObjectType, entry["type"])], schema_defs),
+                    realize_input_schema([entry["type"]], schema_defs),
                 )
             if entry["type"] == "array":
                 items = entry["items"] if not isinstance(entry["items"], str) else [entry["items"]]
@@ -374,7 +373,10 @@ def load_job_order(
             content_types=CWL_CONTENT_TYPES,
         )
 
-    if job_order_object is not None and "http://commonwl.org/cwltool#overrides" in job_order_object:
+    if (
+        isinstance(job_order_object, CommentedMap)
+        and "http://commonwl.org/cwltool#overrides" in job_order_object
+    ):
         ov_uri = file_uri(job_order_file or input_basedir)
         overrides_list.extend(resolve_overrides(job_order_object, ov_uri, tool_file_uri))
         del job_order_object["http://commonwl.org/cwltool#overrides"]
@@ -1289,7 +1291,7 @@ def main(
                 if isinstance(err.code, int):
                     return err.code
                 else:
-                    _logger.debug("Non-integer SystemExit: %s", err.code)
+                    _logger.debug("Non-integer SystemExit: %s", err.code, exc_info=args.debug)
                     return 1
 
             del args.workflow
