@@ -1,6 +1,6 @@
 import os
 from pathlib import Path
-from typing import Any, List, Optional
+from typing import Any, Optional
 from urllib.parse import urljoin, urlsplit
 
 import pytest
@@ -25,7 +25,7 @@ class CWLTestFetcher(Fetcher):
     ) -> None:
         """Create a Fetcher that provides a fixed result for testing purposes."""
 
-    def fetch_text(self, url: str, content_types: Optional[List[str]] = None) -> str:
+    def fetch_text(self, url: str, content_types: Optional[list[str]] = None) -> str:
         if url == "baz:bar/foo.cwl":
             return """
 cwlVersion: v1.0
