@@ -1,6 +1,5 @@
 import json
 from io import StringIO
-from typing import Dict, List
 
 import pytest
 
@@ -76,7 +75,7 @@ override_parameters = [
 
 @needs_docker
 @pytest.mark.parametrize("parameters,result", override_parameters)
-def test_overrides(parameters: List[str], result: Dict[str, str]) -> None:
+def test_overrides(parameters: list[str], result: dict[str, str]) -> None:
     sio = StringIO()
 
     assert main(parameters, stdout=sio) == 0
@@ -119,7 +118,7 @@ failing_override_parameters = [
 
 @needs_docker
 @pytest.mark.parametrize("parameters,expected_error", failing_override_parameters)
-def test_overrides_fails(parameters: List[str], expected_error: str) -> None:
+def test_overrides_fails(parameters: list[str], expected_error: str) -> None:
     sio = StringIO()
 
     assert main(parameters, stderr=sio) == 1
