@@ -6,9 +6,7 @@ from .util import get_data
 def test_target() -> None:
     """Test --target option successful."""
     test_file = "tests/wf/scatter-wf4.cwl"
-    exit_code = main(
-        ["--target", "out", get_data(test_file), "--inp1", "INP1", "--inp2", "INP2"]
-    )
+    exit_code = main(["--target", "out", get_data(test_file), "--inp1", "INP1", "--inp2", "INP2"])
     assert exit_code == 0
 
 
@@ -32,7 +30,5 @@ def test_wrong_target() -> None:
 def test_target_packed() -> None:
     """Test --target option with packed workflow schema."""
     test_file = "tests/wf/scatter-wf4.json"
-    exit_code = main(
-        ["--target", "out", get_data(test_file), "--inp1", "INP1", "--inp2", "INP2"]
-    )
+    exit_code = main(["--target", "out", get_data(test_file), "--inp1", "INP1", "--inp2", "INP2"])
     assert exit_code == 0
